ApplicationEntitlementsBuilder

Struct ApplicationEntitlementsBuilder 

pub struct ApplicationEntitlementsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> ApplicationEntitlementsBuilder<S>

pub fn build(self) -> ApplicationEntitlements
where S: IsComplete,

Finish building and return the requested object

pub fn certificates( self, value: Vec<HeldCertificate>, ) -> ApplicationEntitlementsBuilder<SetCertificates<S>>
where S::Certificates: IsUnset,

Required.

The certificates Canopy holds for it.

pub fn domains( self, value: Vec<String>, ) -> ApplicationEntitlementsBuilder<SetDomains<S>>
where S::Domains: IsUnset,

Required.

The domains its group controls.

pub fn may_manage_dns( self, value: bool, ) -> ApplicationEntitlementsBuilder<SetMayManageDns<S>>
where S::MayManageDns: IsUnset,

Required.

Whether this application may manage its own DNS records.

pub fn may_manage_tls( self, value: bool, ) -> ApplicationEntitlementsBuilder<SetMayManageTls<S>>
where S::MayManageTls: IsUnset,

Required.

Whether this application may obtain its own TLS certificates.

pub fn paused(self, value: bool) -> ApplicationEntitlementsBuilder<SetPaused<S>>
where S::Paused: IsUnset,

Required.

Whether Canopy is currently making no new changes on its behalf.

pub fn registered_names( self, value: Vec<String>, ) -> ApplicationEntitlementsBuilder<SetRegisteredNames<S>>
where S::RegisteredNames: IsUnset,

Required.

The names it has registered addresses for.

pub fn type_( self, value: ApplicationType, ) -> ApplicationEntitlementsBuilder<SetType<S>>
where S::Type: IsUnset,

Required.

The type of application these entitlements belong to.

A reporter correlates an entry to a workload it runs by the machine it asked as and this type. Canopy’s own identifier for the application is internal and never on the wire.