#[non_exhaustive]pub struct BackupCapabilitiesArgs {
pub types: Vec<String>,
}Expand description
Request body for registering the backup types a server can run.
JSON schema
{
"description": "Request body for registering the backup types a server can run.",
"type": "object",
"required": [
"types"
],
"properties": {
"types": {
"description": "The backup types this server is able to run. Each type is a plain\nstring (e.g. `tamanu-postgres`); custom type names are accepted.",
"type": "array",
"items": {
"type": "string"
}
}
}
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.types: Vec<String>The backup types this server is able to run. Each type is a plain
string (e.g. tamanu-postgres); custom type names are accepted.
Implementations
Sourceimpl BackupCapabilitiesArgs
impl BackupCapabilitiesArgs
Sourcepub fn builder() -> BackupCapabilitiesArgsBuilder
pub fn builder() -> BackupCapabilitiesArgsBuilder
Create an instance of BackupCapabilitiesArgs using the builder syntax