#[non_exhaustive]pub struct BackupTarget {
pub bucket: String,
pub prefix: String,
pub region: String,
pub repo_password: Redacted<String>,
pub storage: String,
}Expand description
The backup storage target for the calling server’s group: where the backup repository lives and the passphrase to open it.
JSON schema
{
"description": "The backup storage target for the calling server's group: where the backup\nrepository lives and the passphrase to open it.",
"type": "object",
"required": [
"bucket",
"prefix",
"region",
"repo_password",
"storage"
],
"properties": {
"bucket": {
"description": "Name of the S3 bucket holding the group's backup repository.",
"type": "string"
},
"prefix": {
"description": "Key prefix within the bucket under which the repository lives. Normally\nempty (the repository is at the bucket root).",
"type": "string"
},
"region": {
"description": "AWS region of the bucket.",
"type": "string"
},
"repo_password": {
"description": "Passphrase for the group's backup repository (a Kopia repository).",
"$ref": "#/definitions/CanopySecret"
},
"storage": {
"description": "Kind of storage backend. Always `\"s3\"`.",
"type": "string"
}
}
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bucket: StringName of the S3 bucket holding the group’s backup repository.
prefix: StringKey prefix within the bucket under which the repository lives. Normally empty (the repository is at the bucket root).
region: StringAWS region of the bucket.
repo_password: Redacted<String>Passphrase for the group’s backup repository (a Kopia repository).
storage: StringKind of storage backend. Always "s3".
Implementations
Sourceimpl BackupTarget
impl BackupTarget
Sourcepub fn builder() -> BackupTargetBuilder
pub fn builder() -> BackupTargetBuilder
Create an instance of BackupTarget using the builder syntax