BackupTargetBuilder

Struct BackupTargetBuilder 

pub struct BackupTargetBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> BackupTargetBuilder<S>

pub fn build(self) -> BackupTarget
where S: IsComplete,

Finish building and return the requested object

pub fn bucket(self, value: String) -> BackupTargetBuilder<SetBucket<S>>
where S::Bucket: IsUnset,

Required.

Name of the S3 bucket holding the group’s backup repository.

pub fn prefix(self, value: String) -> BackupTargetBuilder<SetPrefix<S>>
where S::Prefix: IsUnset,

Required.

Key prefix within the bucket under which the repository lives. Normally empty (the repository is at the bucket root).

pub fn region(self, value: String) -> BackupTargetBuilder<SetRegion<S>>
where S::Region: IsUnset,

Required.

AWS region of the bucket.

pub fn repo_password( self, value: Redacted<String>, ) -> BackupTargetBuilder<SetRepoPassword<S>>
where S::RepoPassword: IsUnset,

Required.

Passphrase for the group’s backup repository (a Kopia repository).

pub fn storage(self, value: String) -> BackupTargetBuilder<SetStorage<S>>
where S::Storage: IsUnset,

Required.

Kind of storage backend. Always "s3".