CompleteArgsBuilder

Struct CompleteArgsBuilder 

pub struct CompleteArgsBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> CompleteArgsBuilder<S>

pub fn build(self) -> CompleteArgs
where S: IsComplete,

Finish building and return the requested object

pub fn nonce(self, value: String) -> CompleteArgsBuilder<SetNonce<S>>
where S::Nonce: IsUnset,

Required.

Base64-standard-encoded challenge nonce returned when enrollment was started.

pub fn server_id(self, value: Uuid) -> CompleteArgsBuilder<SetServerId<S>>
where S::ServerId: IsUnset,

Required.

ID of the machine being enrolled. Must match the value used when starting enrollment.

pub fn signature(self, value: String) -> CompleteArgsBuilder<SetSignature<S>>
where S::Signature: IsUnset,

Required.

Base64-standard-encoded ASN.1 DER ECDSA (P-256, SHA-256) signature over the challenge transcript, proving possession of the device’s private key. The transcript is the byte concatenation of: the raw challenge nonce, the raw 16 bytes of the machine ID, the DER SPKI of the device public key, and — only when channel binding was flagged as required — the connection’s TLS exported keying material.

pub fn spki(self, value: String) -> CompleteArgsBuilder<SetSpki<S>>
where S::Spki: IsUnset,

Optional (Some / Option setters). Base64-standard-encoded DER SPKI of the device’s public key. Only required when enrolling over a transport with no client certificate to read the key from; must match the key used when enrollment was started.

pub fn maybe_spki( self, value: Option<String>, ) -> CompleteArgsBuilder<SetSpki<S>>
where S::Spki: IsUnset,

Optional (Some / Option setters). Base64-standard-encoded DER SPKI of the device’s public key. Only required when enrolling over a transport with no client certificate to read the key from; must match the key used when enrollment was started.