#[non_exhaustive]pub struct CompleteResponse {
pub device_id: Uuid,
pub server_id: Uuid,
}Expand description
Result of a successful enrollment.
JSON schema
{
"description": "Result of a successful enrollment.",
"type": "object",
"required": [
"device_id",
"server_id"
],
"properties": {
"device_id": {
"description": "The device identity created or reused for this enrollment. The\ndevice authenticates as this ID from now on.",
"type": "string",
"format": "uuid"
},
"server_id": {
"description": "The machine the device is now enrolled against.",
"type": "string",
"format": "uuid"
}
}
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.device_id: UuidThe device identity created or reused for this enrollment. The device authenticates as this ID from now on.
server_id: UuidThe machine the device is now enrolled against.
Implementations
Sourceimpl CompleteResponse
impl CompleteResponse
Sourcepub fn builder() -> CompleteResponseBuilder
pub fn builder() -> CompleteResponseBuilder
Create an instance of CompleteResponse using the builder syntax