pub struct IntentDescriptorBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> IntentDescriptorBuilder<S>
impl<S: State> IntentDescriptorBuilder<S>
Sourcepub fn build(self) -> IntentDescriptorwhere
S: IsComplete,
pub fn build(self) -> IntentDescriptorwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn description(
self,
value: String,
) -> IntentDescriptorBuilder<SetDescription<S>>where
S::Description: IsUnset,
pub fn description(
self,
value: String,
) -> IntentDescriptorBuilder<SetDescription<S>>where
S::Description: IsUnset,
Sourcepub fn maybe_description(
self,
value: Option<String>,
) -> IntentDescriptorBuilder<SetDescription<S>>where
S::Description: IsUnset,
pub fn maybe_description(
self,
value: Option<String>,
) -> IntentDescriptorBuilder<SetDescription<S>>where
S::Description: IsUnset,
Sourcepub fn intent(self, value: String) -> IntentDescriptorBuilder<SetIntent<S>>where
S::Intent: IsUnset,
pub fn intent(self, value: String) -> IntentDescriptorBuilder<SetIntent<S>>where
S::Intent: IsUnset,
Required.
Name of the intent: an arbitrary identifier chosen by the consumer
(e.g. verify); any name may be advertised.
Sourcepub fn params(self, value: BTreeMap) -> IntentDescriptorBuilder<SetParams<S>>where
S::Params: IsUnset,
pub fn params(self, value: BTreeMap) -> IntentDescriptorBuilder<SetParams<S>>where
S::Params: IsUnset,
Sourcepub fn maybe_params(
self,
value: Option<BTreeMap>,
) -> IntentDescriptorBuilder<SetParams<S>>where
S::Params: IsUnset,
pub fn maybe_params(
self,
value: Option<BTreeMap>,
) -> IntentDescriptorBuilder<SetParams<S>>where
S::Params: IsUnset,
Sourcepub fn semantics(
self,
value: Vec<String>,
) -> IntentDescriptorBuilder<SetSemantics<S>>where
S::Semantics: IsUnset,
pub fn semantics(
self,
value: Vec<String>,
) -> IntentDescriptorBuilder<SetSemantics<S>>where
S::Semantics: IsUnset,
Required.
Behaviours this intent opts into. Recognised values are check (a
health report is expected for each replica), once (a given snapshot
is only ever dispatched to a replica once, rather than repeatedly
until overdue), and url (a replica’s health report includes a link
to it). Unrecognised values are stored but have no effect.