#[non_exhaustive]pub struct RestoreCredentials {
pub credentials: CredentialProcessOutput,
pub repo_password: Redacted<String>,
}Expand description
Read-only S3 credentials plus the repository passphrase for one group and backup type: everything needed to open the group’s backup repository and read a snapshot out of it.
JSON schema
{
"description": "Read-only S3 credentials plus the repository passphrase for one group and\nbackup type: everything needed to open the group's backup repository and\nread a snapshot out of it.",
"type": "object",
"required": [
"credentials",
"repo_password"
],
"properties": {
"credentials": {
"description": "Temporary read-only AWS credentials in the `credential_process` output\nformat, valid for at most one hour.",
"$ref": "#/components/schemas/CredentialProcessOutput"
},
"repo_password": {
"description": "Passphrase for the group's backup repository (a Kopia repository).",
"$ref": "#/definitions/CanopySecret"
}
}
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.credentials: CredentialProcessOutputTemporary read-only AWS credentials in the credential_process output
format, valid for at most one hour.
repo_password: Redacted<String>Passphrase for the group’s backup repository (a Kopia repository).
Implementations
Sourceimpl RestoreCredentials
impl RestoreCredentials
Sourcepub fn builder() -> RestoreCredentialsBuilder
pub fn builder() -> RestoreCredentialsBuilder
Create an instance of RestoreCredentials using the builder syntax