#[non_exhaustive]pub struct RestoreCredentialsArgs {
pub group: Uuid,
pub run_id: Option<Uuid>,
pub type_: String,
}Expand description
Request body for minting read-only restore credentials.
JSON schema
{
"description": "Request body for minting read-only restore credentials.",
"type": "object",
"required": [
"group",
"type"
],
"properties": {
"group": {
"description": "The server group whose backup repository to read.",
"type": "string",
"format": "uuid"
},
"run_id": {
"description": "This must be the run-uuid the client minted for this run.\nThe field is optional only so older clients don't break; it WILL be made\nmandatory in future.",
"type": [
"string",
"null"
],
"format": "uuid"
},
"type": {
"description": "The backup type to restore (e.g. `tamanu-postgres`).",
"type": "string"
}
}
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.group: UuidThe server group whose backup repository to read.
run_id: Option<Uuid>This must be the run-uuid the client minted for this run. The field is optional only so older clients don’t break; it WILL be made mandatory in future.
type_: StringThe backup type to restore (e.g. tamanu-postgres).
Implementations
Sourceimpl RestoreCredentialsArgs
impl RestoreCredentialsArgs
Sourcepub fn builder() -> RestoreCredentialsArgsBuilder
pub fn builder() -> RestoreCredentialsArgsBuilder
Create an instance of RestoreCredentialsArgs using the builder syntax