#[non_exhaustive]pub struct SnippetResponse {
pub description: Option<String>,
pub sql: String,
}Expand description
A single named SQL snippet from the bestool snippet library.
JSON schema
{
"description": "A single named SQL snippet from the bestool snippet library.",
"type": "object",
"required": [
"sql"
],
"properties": {
"description": {
"description": "Human-readable explanation of what the snippet does, if the author\nprovided one.",
"type": [
"string",
"null"
]
},
"sql": {
"description": "The snippet's SQL text.",
"type": "string"
}
}
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.description: Option<String>Human-readable explanation of what the snippet does, if the author provided one.
sql: StringThe snippet’s SQL text.
Implementations
Sourceimpl SnippetResponse
impl SnippetResponse
Sourcepub fn builder() -> SnippetResponseBuilder
pub fn builder() -> SnippetResponseBuilder
Create an instance of SnippetResponse using the builder syntax