pub struct TargetReportBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> TargetReportBuilder<S>
impl<S: State> TargetReportBuilder<S>
Sourcepub fn build(self) -> TargetReportwhere
S: IsComplete,
pub fn build(self) -> TargetReportwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn detail(
self,
value: Map<String, Value>,
) -> TargetReportBuilder<SetDetail<S>>where
S::Detail: IsUnset,
pub fn detail(
self,
value: Map<String, Value>,
) -> TargetReportBuilder<SetDetail<S>>where
S::Detail: IsUnset,
Required.
Everything the reporter has to say about this target beyond its checks. Recorded verbatim against the target it was attached to.
Sourcepub fn health(
self,
value: Vec<HealthCheck>,
) -> TargetReportBuilder<SetHealth<S>>where
S::Health: IsUnset,
pub fn health(
self,
value: Vec<HealthCheck>,
) -> TargetReportBuilder<SetHealth<S>>where
S::Health: IsUnset,
Sourcepub fn maybe_health(
self,
value: Option<Vec<HealthCheck>>,
) -> TargetReportBuilder<SetHealth<S>>where
S::Health: IsUnset,
pub fn maybe_health(
self,
value: Option<Vec<HealthCheck>>,
) -> TargetReportBuilder<SetHealth<S>>where
S::Health: IsUnset,