pub struct ApplicationEntitlementsBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> ApplicationEntitlementsBuilder<S>
impl<S: State> ApplicationEntitlementsBuilder<S>
Sourcepub fn build(self) -> ApplicationEntitlementswhere
S: IsComplete,
pub fn build(self) -> ApplicationEntitlementswhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn certificates(
self,
value: Vec<HeldCertificate>,
) -> ApplicationEntitlementsBuilder<SetCertificates<S>>where
S::Certificates: IsUnset,
pub fn certificates(
self,
value: Vec<HeldCertificate>,
) -> ApplicationEntitlementsBuilder<SetCertificates<S>>where
S::Certificates: IsUnset,
Required.
The certificates Canopy holds for it.
Sourcepub fn domains(
self,
value: Vec<String>,
) -> ApplicationEntitlementsBuilder<SetDomains<S>>where
S::Domains: IsUnset,
pub fn domains(
self,
value: Vec<String>,
) -> ApplicationEntitlementsBuilder<SetDomains<S>>where
S::Domains: IsUnset,
Required.
The domains its group controls.
Sourcepub fn may_manage_dns(
self,
value: bool,
) -> ApplicationEntitlementsBuilder<SetMayManageDns<S>>where
S::MayManageDns: IsUnset,
pub fn may_manage_dns(
self,
value: bool,
) -> ApplicationEntitlementsBuilder<SetMayManageDns<S>>where
S::MayManageDns: IsUnset,
Required.
Whether this application may manage its own DNS records.
Sourcepub fn may_manage_tls(
self,
value: bool,
) -> ApplicationEntitlementsBuilder<SetMayManageTls<S>>where
S::MayManageTls: IsUnset,
pub fn may_manage_tls(
self,
value: bool,
) -> ApplicationEntitlementsBuilder<SetMayManageTls<S>>where
S::MayManageTls: IsUnset,
Required.
Whether this application may obtain its own TLS certificates.
Sourcepub fn paused(self, value: bool) -> ApplicationEntitlementsBuilder<SetPaused<S>>where
S::Paused: IsUnset,
pub fn paused(self, value: bool) -> ApplicationEntitlementsBuilder<SetPaused<S>>where
S::Paused: IsUnset,
Required.
Whether Canopy is currently making no new changes on its behalf.
Sourcepub fn registered_names(
self,
value: Vec<String>,
) -> ApplicationEntitlementsBuilder<SetRegisteredNames<S>>where
S::RegisteredNames: IsUnset,
pub fn registered_names(
self,
value: Vec<String>,
) -> ApplicationEntitlementsBuilder<SetRegisteredNames<S>>where
S::RegisteredNames: IsUnset,
Required.
The names it has registered addresses for.
Sourcepub fn type_(
self,
value: ApplicationType,
) -> ApplicationEntitlementsBuilder<SetType<S>>where
S::Type: IsUnset,
pub fn type_(
self,
value: ApplicationType,
) -> ApplicationEntitlementsBuilder<SetType<S>>where
S::Type: IsUnset,
Required.
The type of application these entitlements belong to.
A reporter correlates an entry to a workload it runs by the machine it asked as and this type. Canopy’s own identifier for the application is internal and never on the wire.