IntentDescriptorBuilder

Struct IntentDescriptorBuilder 

pub struct IntentDescriptorBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> IntentDescriptorBuilder<S>

pub fn build(self) -> IntentDescriptor
where S: IsComplete,

Finish building and return the requested object

pub fn description( self, value: String, ) -> IntentDescriptorBuilder<SetDescription<S>>
where S::Description: IsUnset,

Optional (Some / Option setters). Human-readable description of the intent, if provided.

pub fn maybe_description( self, value: Option<String>, ) -> IntentDescriptorBuilder<SetDescription<S>>
where S::Description: IsUnset,

Optional (Some / Option setters). Human-readable description of the intent, if provided.

pub fn intent(self, value: String) -> IntentDescriptorBuilder<SetIntent<S>>
where S::Intent: IsUnset,

Required.

Name of the intent: an arbitrary identifier chosen by the consumer (e.g. verify); any name may be advertised.

pub fn params(self, value: BTreeMap) -> IntentDescriptorBuilder<SetParams<S>>
where S::Params: IsUnset,

Optional (Some / Option setters). Configurable parameters this intent accepts per replica, keyed by parameter name.

pub fn maybe_params( self, value: Option<BTreeMap>, ) -> IntentDescriptorBuilder<SetParams<S>>
where S::Params: IsUnset,

Optional (Some / Option setters). Configurable parameters this intent accepts per replica, keyed by parameter name.

pub fn semantics( self, value: Vec<String>, ) -> IntentDescriptorBuilder<SetSemantics<S>>
where S::Semantics: IsUnset,

Required.

Behaviours this intent opts into. Recognised values are check (a health report is expected for each replica), once (a given snapshot is only ever dispatched to a replica once, rather than repeatedly until overdue), and url (a replica’s health report includes a link to it). Unrecognised values are stored but have no effect.