#[non_exhaustive]pub struct RestoreCapabilitiesArgs {
pub intents: Vec<IntentDescriptor>,
}Expand description
Request body for registering the restore intents a consumer device can satisfy.
JSON schema
{
"description": "Request body for registering the restore intents a consumer device can\nsatisfy.",
"type": "object",
"required": [
"intents"
],
"properties": {
"intents": {
"description": "The intents this device can satisfy — arbitrary consumer-chosen\nidentifiers (e.g. `verify`) — each with its description, the semantics\nit opts into, and the schema of the parameters it accepts. Replaces the\ndevice's previously advertised set wholesale.",
"type": "array",
"items": {
"$ref": "#/components/schemas/IntentDescriptor"
}
}
}
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.intents: Vec<IntentDescriptor>The intents this device can satisfy — arbitrary consumer-chosen
identifiers (e.g. verify) — each with its description, the semantics
it opts into, and the schema of the parameters it accepts. Replaces the
device’s previously advertised set wholesale.
Implementations
Sourceimpl RestoreCapabilitiesArgs
impl RestoreCapabilitiesArgs
Sourcepub fn builder() -> RestoreCapabilitiesArgsBuilder
pub fn builder() -> RestoreCapabilitiesArgsBuilder
Create an instance of RestoreCapabilitiesArgs using the builder syntax